diff --git a/api/current.txt b/api/current.txt
index 7c7ebb2dcc593..667f5648bfb42 100644
--- a/api/current.txt
+++ b/api/current.txt
@@ -18551,7 +18551,7 @@ package android.print {
method public android.print.PrintAttributes getAttributes();
method public int getId();
method public java.lang.CharSequence getLabel();
- method public android.print.PageRange[] getPageRanges();
+ method public android.print.PageRange[] getPages();
method public android.print.PrinterId getPrinterId();
method public int getState();
method public java.lang.String getTag();
@@ -18572,10 +18572,6 @@ package android.print {
method public android.print.PrintJob print(java.lang.String, android.print.PrintAdapter, android.print.PrintAttributes);
}
- public static abstract interface PrintManager.PrintJobStateListener {
- method public abstract void onStateChanged(int);
- }
-
public final class PrinterId implements android.os.Parcelable {
method public int describeContents();
method public java.lang.String getLocalId();
diff --git a/core/java/android/print/PrintManager.java b/core/java/android/print/PrintManager.java
index df14a5c6c9860..32a0f5a0a360a 100644
--- a/core/java/android/print/PrintManager.java
+++ b/core/java/android/print/PrintManager.java
@@ -69,13 +69,6 @@ public final class PrintManager {
private final Handler mHandler;
- /**
- * Listener for the state of a print job.
- */
- public static interface PrintJobStateListener {
- public void onStateChanged(int state);
- }
-
/**
* Creates a new instance.
*
diff --git a/core/java/android/print/PrintJobInfo.java b/core/java/android/print/PrintJobInfo.java
index 1a5d67104f431..72d6057e53239 100644
--- a/core/java/android/print/PrintJobInfo.java
+++ b/core/java/android/print/PrintJobInfo.java
@@ -261,22 +261,22 @@ public final class PrintJobInfo implements Parcelable {
}
/**
* Gets the included page ranges.
*
- * @return The included page ranges or null if not set.
+ * @return The included pages or null if not set.
*/
- public PageRange[] getPageRanges() {
+ public PageRange[] getPages() {
return mPageRanges;
}
/**
* Sets the included page ranges.
*
- * @return The included page ranges.
+ * @return The included pages.
*
* @hide
*/
- public void setPageRanges(PageRange[] pageRanges) {
+ public void setPages(PageRange[] pageRanges) {
mPageRanges = pageRanges;
}
@@ -261,22 +261,22 @@ public final class PrintJobInfo implements Parcelable {
}
/**
- * Gets the included page ranges.
+ * Gets the included pages.
*
@@ -261,22 +261,22 @@ public final class PrintJobInfo implements Parcelable {
}
/**
- * Sets the included page ranges.
+ * Sets the included pages.
*